##  Step 3. Report and Communicate
As in the previous phases, you will evolve your dashboards for the different stakeholder groups and leverage the above reports to share key insights.
![Illustrative Dashboard for Phase 3 \(Explore\)](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27434a2b7a441014bd7ab9a010abe9a4_LowRes.gif)
Illustrative Dashboard for Phase 3 (Explore)
In addition, you can add the following KPIs and views to measure the progress of your transformation program:
  * ERP Roadmap with Initiatives and milestones: Roadmap Report providing a high-level overview of the ERP transformation timeline, different projects, and Milestones. It also serves as high-level guidance on which Initiatives to focus on first. This will be a more detailed view since more detailed data collected in phase 3.
![ERP Roadmap with Initiatives and Milestones](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275176fe7a441014b58c81fa852e4905_LowRes.png)
ERP Roadmap with Initiatives and Milestones
  * Quality of Initiatives: Overview of KPIs providing a first high-level overview of the number of Initiatives that are supporting the ERP Transformation, and for how many of those Initiatives mandatory attributes have been filled/assessed (Responsibles, Lifecycles, Business Risks).
![Quality of Initiatives showing the status of Initiative completeness](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274ad2477a4410149691a8100c4964e7_LowRes.png)
Quality of Initiatives showing the status of Initiative completeness
  * As-Is Application Landscape and To-Be Application Landscape: Build Application Landscape Reports for as-is and the future-state landscape, then add them to the Dashboard to show the contrast and status of progress.
![Application Landscape Reports showing the contrast between as-is and the future-state landscape.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275358307a441014b2a7fdbaa2f1d733_LowRes.png)
Application Landscape Reports showing the contrast between as-is and the future-state landscape.


**Note**
You can use the [SAP LeanIX Diagrams](https://help.sap.com/docs/leanix/ea/diagrams?locale=en-US&state=PRODUCTION&version=CLOUD) to detail your solution architecture and engage with more technical roles, such as Solution Architects.
At the end of this phase, you have all the data needed for your management to decide on the most suitable transformation scenario, which you will execute in [phase 4 (Realize)](https://help.sap.com/docs/leanix/ea/erp-transformation-realize-deploy-run?locale=en-US&state=PRODUCTION&version=CLOUD "Run transformations, measure, and monitor progress using SAP LeanIX. Achieve transparency, communicate developments, and reflect on architecture changes for a successful transformation journey.").
YesNo
Send
